pub struct Client {
pub incoming: Receiver<String>,
pub outgoing: Sender<Command>,
/* private fields */
}Expand description
A higher-level client wrapper that provides incoming/outgoing channels and a graceful shutdown handle for the background connection task.
Fields
incoming: Receiver<String>Incoming lines received from the server.
outgoing: Sender<Command>Send Command values to be written to the server.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn start(addr: String, api_key: String) -> Self
pub fn start(addr: String, api_key: String) -> Self
Spawn a background task to maintain a long-lived connection to addr.
Returns a Client that can send commands and receive incoming lines.
Sourcepub async fn send(&self, cmd: Command) -> Result<(), SendError<Command>>
pub async fn send(&self, cmd: Command) -> Result<(), SendError<Command>>
Asynchronously send a Command to the server via the background task.